"use client"

import { type Color, type Image, type ImageColor } from "@/generated/prisma"
import { useGlobalSettings } from "@/hooks/useGlobalSettings"
import clsx from "clsx"
import { EyeOffIcon } from "lucide-react"
import NextImage from "next/image"
import Link from "next/link"
import { GlowingBorderWrapper } from "./GlowingBorderWrapper"
import { TagBadge } from "./TagBadge"

type ImageWithColors = Image & {
  colors?: (ImageColor & { color: Color })[]
}

type ImageCardProps = {
  image: ImageWithColors,
  gallerySlug?: string
  albumSlug?: string
}

export default function ImageCard({ image, gallerySlug, albumSlug }: ImageCardProps) {
  const { showNSFW, animateGlow } = useGlobalSettings()

  const href = `/galleries/${gallerySlug}/${albumSlug}/${image.id}`

  const borderColors =
    image.colors?.map((c) => c.color?.hex).filter((hex): hex is string => Boolean(hex)) ?? []

  const shouldBlur = image.nsfw && !showNSFW

  const content = (
    <div className="group rounded-lg border overflow-hidden hover:shadow-lg transition-shadow bg-background relative">
      <div className="relative aspect-[4/3] w-full bg-muted items-center justify-center">
        <NextImage
          src={`/api/image/thumbnails/${image.fileKey}.webp`}
          alt={image.imageName}
          fill
          className={clsx("object-cover transition duration-300", shouldBlur && "blur-md scale-105")}
        />
        {image.nsfw && (
          <div className="absolute top-1 left-1 z-10 flex gap-1">
            <TagBadge
              label="NSFW"
              variant="destructive"
              icon={<EyeOffIcon size={12} />}
              className="text-xs px-2 py-0.5 inline-flex items-center"
            />
          </div>
        )}
      </div>
      <div className="p-4">
        <h2 className="text-lg font-semibold truncate text-center">{image.imageName}</h2>
      </div>
    </div>
  )

  return (
    <Link href={href}>
      {animateGlow && borderColors.length > 0 ? (
        <GlowingBorderWrapper colors={borderColors}>{content}</GlowingBorderWrapper>
      ) : (
        content
      )}
    </Link>
  )
}
